##  Step 3: View SBOMs in the SBOM Explorer
View ingested SBOMs in the SBOM explorer in SAP LeanIX. The SBOM explorer helps you understand and manage your open-source dependencies within the business context, relating to your applications, teams, and other objects. It allows you to track these dependencies during cybersecurity incidents and take swift action to address risks and compliance issues. For more information, see [SBOM Explorer](https://help.sap.com/docs/leanix/ea/sbom-explorer?locale=en-US&state=PRODUCTION&version=CLOUD "The SBOM explorer helps you understand your open-source libraries' usage, manage them, track them during cybersecurity incidents, and quickly take action to address risks and compliance issues.").
